@@ -9,16 +9,13 @@ Tests for `django-watchman` decorators module.
 
 from __future__ import unicode_literals
 
+import logging
 import unittest
 
-try:
-    from django.urls import reverse
-except ImportError:
-    # Deprecated in Django 1.10
-    from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.test.client import Client
 
-import mock
+from unittest import mock
 
 from watchman import settings as watchman_settings
 from watchman.decorators import check
@@ -85,6 +82,7 @@ class TestWatchmanSingleToken(unittest.TestCase):
 
     def setUp(self):
         self.client = Client()
+        self.logger = logging.getLogger('watchman')
         watchman_settings.WATCHMAN_TOKEN = 'foo'
         watchman_settings.WATCHMAN_TOKENS = None
 
@@ -122,28 +120,55 @@ class TestWatchmanSingleToken(unittest.TestCase):
     #
     # Instead, assert all other response parameters are correct.
     def test_exception_caught_if_no_arguments(self):
+
+        def test_func():
+            raise FakeException('test error')
+
+        self.logger.exception = mock.MagicMock()
+        self.logger.debug = mock.MagicMock()
+        decorated_func = check(test_func)
         keys = ['ok', 'error', 'stacktrace']
-        func = mock.Mock(side_effect=FakeException('example error'))
-        decorated_func = check(func)
         response = decorated_func()
         self.assertIsInstance(response, dict)
         for key in keys:
             self.assertIn(key, response)
         self.assertEqual(response['ok'], False)
-        self.assertEqual(response['error'], 'example error')
+        self.assertEqual(response['error'], 'test error')
         self.assertIsInstance(response['stacktrace'], str)
+        self.logger.debug.assert_called_once_with(
+            "Checking '%s'", 'test_func'
+        )
+        self.logger.exception.assert_called_once_with(
+            "Error calling '%s': %s",
+            'test_func',
+            'test error'
+        )
 
     def test_exception_caught_with_argument(self):
+
+        def test_func(arg):
+            raise FakeException('test error')
+
+        self.logger.exception = mock.MagicMock()
+        self.logger.debug = mock.MagicMock()
+        decorated_func = check(test_func)
         keys = ['ok', 'error', 'stacktrace']
-        func = mock.Mock(side_effect=FakeException('example error'))
-        decorated_func = check(func)
         response = decorated_func('default')
         self.assertIsInstance(response, dict)
         for key in keys:
             self.assertIn(key, response['default'])
         self.assertEqual(response['default']['ok'], False)
-        self.assertEqual(response['default']['error'], 'example error')
+        self.assertEqual(response['default']['error'], 'test error')
         self.assertIsInstance(response['default']['stacktrace'], str)
+        self.logger.debug.assert_called_once_with(
+            "Checking '%s' for '%s'", 'test_func', 'default'
+        )
+        self.logger.exception.assert_called_once_with(
+            "Error calling '%s' for '%s': %s",
+            'test_func',
+            'default',
+            'test error'
+        )
 
     def tearDown(self):
         watchman_settings.WATCHMAN_TOKEN = None
