@@ -1,4 +1,5 @@
 from django.conf import settings
+from watchman.constants import DEFAULT_CHECKS, PAID_CHECKS
 
 # TODO: these should not be module level (https://github.com/mwarkentin/django-watchman/issues/13)
 WATCHMAN_ENABLE_PAID_CHECKS = getattr(settings, 'WATCHMAN_ENABLE_PAID_CHECKS', False)
@@ -8,19 +9,20 @@ WATCHMAN_TOKEN = getattr(settings, 'WATCHMAN_TOKEN', None)
 WATCHMAN_TOKENS = getattr(settings, 'WATCHMAN_TOKENS', None)
 WATCHMAN_TOKEN_NAME = getattr(settings, 'WATCHMAN_TOKEN_NAME', 'watchman-token')
 WATCHMAN_ERROR_CODE = getattr(settings, 'WATCHMAN_ERROR_CODE', 500)
+WATCHMAN_EMAIL_SENDER = getattr(settings, 'WATCHMAN_EMAIL_SENDER', 'watchman@example.com')
 WATCHMAN_EMAIL_RECIPIENTS = getattr(settings, 'WATCHMAN_EMAIL_RECIPIENTS', ['to@example.com'])
 WATCHMAN_EMAIL_HEADERS = getattr(settings, 'WATCHMAN_EMAIL_HEADERS', {})
 
-DEFAULT_CHECKS = (
-    'watchman.checks.caches',
-    'watchman.checks.databases',
-    'watchman.checks.storage',
-)
-PAID_CHECKS = (
-    'watchman.checks.email',
-)
+WATCHMAN_CACHES = getattr(settings, 'WATCHMAN_CACHES', settings.CACHES)
+WATCHMAN_DATABASES = getattr(settings, 'WATCHMAN_DATABASES', settings.DATABASES)
+
+WATCHMAN_DISABLE_APM = getattr(settings, 'WATCHMAN_DISABLE_APM', False)
+
+WATCHMAN_STORAGE_PATH = getattr(settings, 'WATCHMAN_STORAGE_PATH', settings.MEDIA_ROOT)
 
 if WATCHMAN_ENABLE_PAID_CHECKS:
     DEFAULT_CHECKS = DEFAULT_CHECKS + PAID_CHECKS
 
 WATCHMAN_CHECKS = getattr(settings, 'WATCHMAN_CHECKS', DEFAULT_CHECKS)
+
+EXPOSE_WATCHMAN_VERSION = getattr(settings, 'EXPOSE_WATCHMAN_VERSION', False)
